Crate av_metrics_decoders

Crate av_metrics_decoders 

This crate providers ready-made decoders for use with av-metrics or other tools as needed.

No decoders are enabled by default. They must be enabled via Cargo features.

Currently supported decoder features: y4m

Structs

Frame
Represents a raw video frame
Plane
One data plane of a frame.
VideoDetails
A Structure containing Video Details as per Plane’s Config

Enums

ChromaSampling
Chroma subsampling format

Traits

CastFromPrimitive
Trait for casting between primitive types.
Decoder
A trait for allowing metrics to decode generic video formats.
Pixel
A type that can be used as a pixel type.