This crate providers ready-made decoders for use with av-metrics or other tools as needed.
No decoders are enabled by default. They must be enabled via Cargo features.
Currently supported decoder features: y4m
Structs
- Frame
- Represents a raw video frame
- Plane
- One data plane of a frame.
- Video
Details - A Structure containing Video Details as per Plane’s Config
Enums
- Chroma
Sampling - Chroma subsampling format
Traits
- Cast
From Primitive - Trait for casting between primitive types.
- Decoder
- A trait for allowing metrics to decode generic video formats.
- Pixel
- A type that can be used as a pixel type.